Skip to main contentCrate vortex_sequence
Source - Sequence
- Represents the equation A[i] = a * i + b.
This can be used for compression, fast comparisons and also for row ids.
- SequenceData
- An array representing the equation
A[i] = base + i * multiplier. - SequenceDataParts
- initialize
- Initialize sequence encoding in the given session.
- sequence_encode
- Encodes a primitive array into a sequence array, this is possible if:
- SequenceArray
- Represents the equation A[i] = a * i + b.
This can be used for compression, fast comparisons and also for row ids.
A
Sequence-encoded Vortex array.